
# Slot: has count


number of things with a particular property

URI: [biolink:has_count](https://w3id.org/biolink/vocab/has_count)

## Domain and Range

[FrequencyQuantifier](FrequencyQuantifier.md) ->  <sub>OPT</sub> [Integer](Integer.md)

## Parents

 *  is_a: [aggregate statistic](aggregate_statistic.md)

## Children

 *  [has count](variant_to_population_association_has_count.md)

## Used by

 * [FrequencyQuantifier](FrequencyQuantifier.md)
 * [VariantToPopulationAssociation](VariantToPopulationAssociation.md)
